@@ -6,6 +6,7 @@ from ..const import (
     BODY_TYPE,
     DATA,
     DEVICE_TYPE,
+    ON_OFF,
     UNIT,
 )
 from .protocol import ScreenLogicProtocol
@@ -24,33 +25,36 @@ async def async_request_pool_status(protocol: ScreenLogicProtocol, data: dict) -
 def decode_pool_status(buff: bytes, data: dict) -> None:
     config = data.setdefault(DATA.KEY_CONFIG, {})
 
-    ok, offset = getSome("I", buff, 0)
+    ok, offset = getSome("I", buff, 0)  # byte offset 0
     config["ok"] = ok
 
-    freezeMode, offset = getSome("B", buff, offset)
-    config["freeze_mode"] = {"name": "Freeze Mode", "value": freezeMode}
+    freezeMode, offset = getSome("B", buff, offset)  # byte offset 4
+    config["freeze_mode"] = {
+        "name": "Freeze Mode",
+        "value": ON_OFF.from_bool(freezeMode & 0x08),
+    }
 
-    remotes, offset = getSome("B", buff, offset)
+    remotes, offset = getSome("B", buff, offset)  # 5
     config["remotes"] = {"name": "Remotes", "value": remotes}
 
-    poolDelay, offset = getSome("B", buff, offset)
+    poolDelay, offset = getSome("B", buff, offset)  # 6
     config["pool_delay"] = {"name": "Pool Delay", "value": poolDelay}
 
-    spaDelay, offset = getSome("B", buff, offset)
+    spaDelay, offset = getSome("B", buff, offset)  # 7
     config["spa_delay"] = {"name": "Spa Delay", "value": spaDelay}
 
-    cleanerDelay, offset = getSome("B", buff, offset)
+    cleanerDelay, offset = getSome("B", buff, offset)  # 8
     config["cleaner_delay"] = {"name": "Cleaner Delay", "value": cleanerDelay}
 
-    config[f"unknown_at_offset_{offset:02}"], offset = getSome("B", buff, offset)
-    config[f"unknown_at_offset_{offset:02}"], offset = getSome("B", buff, offset)
-    config[f"unknown_at_offset_{offset:02}"], offset = getSome("B", buff, offset)
+    config[f"unknown_at_offset_{offset:02}"], offset = getSome("B", buff, offset)  # 9
+    config[f"unknown_at_offset_{offset:02}"], offset = getSome("B", buff, offset)  # 10
+    config[f"unknown_at_offset_{offset:02}"], offset = getSome("B", buff, offset)  # 11
 
     sensors = data.setdefault(DATA.KEY_SENSORS, {})
 
     temperature_unit = getTemperatureUnit(data)
 
-    airTemp, offset = getSome("i", buff, offset)
+    airTemp, offset = getSome("i", buff, offset)  # 12
     sensors["air_temperature"] = {
         "name": "Air Temperature",
         "value": airTemp,
@@ -58,7 +62,7 @@ def decode_pool_status(buff: bytes, data: dict) -> None:
         "device_type": DEVICE_TYPE.TEMPERATURE,
     }
 
-    bodiesCount, offset = getSome("I", buff, offset)
+    bodiesCount, offset = getSome("I", buff, offset)  # 16
 
     # Should this default to 2?
     bodiesCount = min(bodiesCount, 2)
